#!/bin/sh
#
# ###################################################################
# Copyright (c) 2005-2011, EMC Corporation. All Rights Reserved.
#
# /etc/init.d/emcp_mond.sh
# This file is a part of EMC PowerPath.
#
# chkconfig: 35 51 51
# description: Starts and stops PowerPath Management Daemon.
#
# Usage : emcp_mond.sh start | stop
#
# ###################################################################
#
### BEGIN INIT INFO
# Provides:          emcp_mond.sh
# Required-Start:
# Required-Stop:
# Default-Start:     3 5
# Default-Stop:      3 5
# Description:       emcp_mond.sh -- Starts and stops PowerPath Management 
#                    Daemon.
### END INIT INFO


PATH=/usr/bin/:/bin:/sbin:/usr/sbin
PPBASE="/etc/opt/emcpower/EMCpower.LINUX-5.6.0.00.00"

# the following are the internationalization specific lines

if [ ! -x /usr/bin/gettext ]; then
gettext()
{
 echo "$*"
}
eval_gettext()
{
 eval "echo \"$*\""
}
else
. gettext.sh
TEXTDOMAIN=PowerPath
export TEXTDOMAIN
TEXTDOMAINDIR=$PPBASE/i18n/catalog

export TEXTDOMAINDIR
export RPM_INSTALL_PREFIX
fi
# end of internationalization

pp_logger ()
{
    msg=$*
    which logger > /dev/null 2>&1

    if [ $? -eq 0 ]
    then
        logger ${msg}
    fi
}

DAEMON=/sbin/emcp_mond
snmpd_pid=`ps -eu root | awk '{for(;NF!=0;){if(getline<=0) break;i=NF;a=split($i,b,"/");if(b[a]=="snmpd"){print $1;}}}'`
mond_pid=`ps -eu root | awk '{for(;NF!=0;){if(getline<=0) break;i=NF;a=split($i,b,"/");if(b[a]=="emcp_mond"){print $1;}}}'`

Option=$1

# Handle RUN TIME Lib Dependencies
case `uname -p` in

    i686*) LD_LIBRARY_PATH=/usr/local/lib:/usr/lib/perl5/5.8.8/i386-linux-thread-multi/CORE:$LD_LIBRARY_PATH
           export LD_LIBRARY_PATH ;;
    x86_64*) LD_LIBRARY_PATH=/usr/local/lib:/usr/lib/perl5/5.8.8/i386-linux-thread-multi/CORE:/usr/local/lib64:/usr/lib64/perl5/5.8.8/x86_64-linux-thread-multi/CORE:$LD_LIBRARY_PATH
           export LD_LIBRARY_PATH ;; 
    ia64*) LD_LIBRARY_PATH=/usr/local/lib:/usr/lib/perl5/5.8.8/ia64-linux-thread-multi/CORE:$LD_LIBRARY_PATH
           export LD_LIBRARY_PATH  ;;
    ppc64*) LD_LIBRARY_PATH=/usr/lib:/usr/lib/perl5/5.8.8/ppc-linux-thread-multi/CORE:$LD_LIBRARY_PATH
           export LD_LIBRARY_PATH  ;;
    s390x*) LD_LIBRARY_PATH=/usr/lib:/usr/lib/perl5/5.8.8/s390x-linux-thread-multi/CORE:$LD_LIBRARY_PATH
           export LD_LIBRARY_PATH  ;;

esac

case ${Option} in
'start')
    if [ -x $DAEMON ]
    then
        if [ "${mond_pid}" != "" ]
        then
            echo "`eval_gettext \"PowerPath Management Daemon is already running\"`"
            exit 0
        fi
        lsmod | grep -w '^emcp' > /dev/null
        if test $? -ne 0 ;
        then
            echo "`eval_gettext \"PowerPath is not running\"`"
            exit 0
        fi

        # If snmpd is not running add -S to the emcp_mond command line to
        # tell emcp_mond to not send out snmp traps.
        snmp_switch=''
        if [ "${snmpd_pid}" = "" ]
        then
            snmp_switch='-S'
        fi
        if [ -f /etc/opt/emcpower/emcp_mond.conf ]
        then
            $DAEMON ${snmp_switch}
            if [ $? -eq 0 ]
            then
                echo "`eval_gettext \"Starting PowerPath Management Daemon\"`"
                pp_logger emcp_mond.sh: Starting PowerPath Management Daemon
            fi
        else
            echo "`eval_gettext \"Missing PowerPath Management Daemon configuration file=/etc/opt/emcpower/emcp_mond.conf\"`"
            pp_logger emcp_mond.sh: Missing PowerPath Management Daemon configuration file=/etc/opt/emcpower/emcp_mond.conf
        fi
    fi
    break ;;
'stop')
    if [ "${mond_pid}" != "" ]
    then
        kill -usr1 ${mond_pid}
        echo "`eval_gettext \"Stopping PowerPath Management Daemon...\"`"
        pp_logger emcp_mond.sh: Stopping PowerPath Management Daemon...
    else
        echo "`eval_gettext \"PowerPath Management Daemon is not running.\"`"
        pp_logger emcp_mond.sh: PowerPath Management Daemon is not running.
    fi
    break ;;
*)
    echo "`eval_gettext \"usage: $0 start | stop\"`"
    ;;
esac

exit 0
